# Version

[Streaming-wds Index](./README.md#streaming-wds-index) / Version

> Auto-generated documentation for [_version](../streaming_wds/_version.py) module.

#### Attributes

- `TYPE_CHECKING` - file generated by setuptools_scm
  don't change, don't track in version control: False
- [Version](#version)
